==> server-0.2.0-sources.jar: com/xebialabs/xltest/serialize/CiJsonMessageBodyReader.java <==
package com.xebialabs.xltest.serialize;

import com.xebialabs.deployit.plugin.api.services.Repository;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.xltype.serialization.CiReader;
import com.xebialabs.xltype.serialization.ConfigurationItemConverter;
import com.xebialabs.xltype.serialization.json.CiJsonReader;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;
import org.jboss.resteasy.plugins.providers.jaxb.json.JsonParsing;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.ws.rs.Consumes;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyReader;
import javax.ws.rs.ext.Provider;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.lang.annotation.Annotation;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Collection;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
public class CiJsonMessageBodyReader implements MessageBodyReader<ConfigurationItem> {

    private Repository repository;

    @Autowired
    public CiJsonMessageBodyReader(Repository repository) {
        this.repository = repository;
    }

    @Override
    public boolean isReadable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        if (Collection.class.isAssignableFrom(type) && genericType instanceof ParameterizedType) {
            type = (Class<?>) ((ParameterizedType) genericType).getActualTypeArguments()[0];
        }

        return ConfigurationItem.class.isAssignableFrom(type);
    }

    @Override
    public ConfigurationItem readFrom(Class<ConfigurationItem> type, Type genericType, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, String> httpHeaders, InputStream entityStream) throws IOException, WebApplicationException {
        ConfigurationItemConverter converter = new ConfigurationItemConverter();
        CiReader reader;
        try {
            reader = new CiJsonReader(new JSONObject(JsonParsing.extractJsonMapString(new InputStreamReader(entityStream))));
        } catch (JSONException e) {
            throw new WebApplicationException(e);
        }

        ConfigurationItem result = converter.readCi(reader);

        converter.resolveReferences(repository);

        return result;
    }

}

==> server-1.0.0-sources.jar: com/xebialabs/xltest/serialize/CiJsonMessageBodyReader.java <==
package com.xebialabs.xltest.serialize;

import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.util.Collection;

import javax.ws.rs.Consumes;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyReader;
import javax.ws.rs.ext.Provider;

import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONObject;
import org.jboss.resteasy.plugins.providers.jaxb.json.JsonParsing;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.xebialabs.deployit.plugin.api.services.Repository;
import com.xebialabs.deployit.plugin.api.udm.ConfigurationItem;
import com.xebialabs.xltype.serialization.CiReader;
import com.xebialabs.xltype.serialization.ConfigurationItemConverter;
import com.xebialabs.xltype.serialization.json.CiJsonReader;

@Component
@Provider
@Consumes({MediaType.APPLICATION_JSON})
public class CiJsonMessageBodyReader implements MessageBodyReader<ConfigurationItem> {

    private Repository repository;
    
    private static final Logger LOG = LoggerFactory.getLogger(CiJsonMessageBodyReader.class);

    @Autowired
    public CiJsonMessageBodyReader(Repository repository) {
        this.repository = repository;
    }

    @Override
    public boolean isReadable(Class<?> type, Type genericType, Annotation[] annotations, MediaType mediaType) {
        if (Collection.class.isAssignableFrom(type) && genericType instanceof ParameterizedType) {
            type = (Class<?>) ((ParameterizedType) genericType).getActualTypeArguments()[0];
        }

        return ConfigurationItem.class.isAssignableFrom(type);
    }

    @Override
    public ConfigurationItem readFrom(Class<ConfigurationItem> type, Type genericType, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, String> httpHeaders, InputStream entityStream) throws IOException, WebApplicationException {
        ConfigurationItemConverter converter = new ConfigurationItemConverter();
        CiReader reader;
        JSONObject json;
        try {
        	json = new JSONObject(JsonParsing.extractJsonMapString(new InputStreamReader(entityStream)));
            reader = new CiJsonReader(json);
        } catch (JSONException e) {
            throw new WebApplicationException(e);
        }
        ConfigurationItem result = null;
        try {
        	result = converter.readCi(reader);
        } catch (IllegalArgumentException e) {
	        LOG.error("Conversion error. Can't handle mapping this json: " + json + " to a CI");
	        throw new IllegalArgumentException(e);
        }

        converter.resolveReferences(repository);

        return result;
    }

}
